@@ -130,7 +130,7 @@ usl.solve.nls <- function(model) {
 #' @seealso \code{\link{usl}}
 #'
 #' @references John C. Nash. nlmrt: Functions for nonlinear least squares
-#'   solutions, 2012. R package version 2012-12.16.
+#'   solutions, 2013. R package version 2013-8.10.
 #'
 #' @importFrom nlmrt nlxb
 #' @keywords internal
@@ -147,9 +147,9 @@ usl.solve.nlxb <- function(model) {
                     lower = c(X1 = 0, sigma = 0, kappa = 0),
                     upper = c(X1 = Inf, sigma = 1, kappa = 1))
 
-  scale.factor = model.fit$coeffs[['X1']]
-  sigma = model.fit$coeffs[['sigma']]
-  kappa = model.fit$coeffs[['kappa']]
+  scale.factor = model.fit$coefficients[['X1']]
+  sigma = model.fit$coefficients[['sigma']]
+  kappa = model.fit$coefficients[['kappa']]
 
   return(list(scale.factor = scale.factor, sigma = sigma, kappa = kappa))
 }
@@ -230,7 +230,7 @@ usl.solve.nlxb <- function(model) {
 #'   Springer, Heidelberg, Germany, 1st edition, 2007.
 #'
 #' @references John C. Nash. nlmrt: Functions for nonlinear least squares
-#'   solutions, 2012. R package version 2012-12.16.
+#'   solutions, 2013. R package version 2013-8.10.
 #'
 #' @examples
 #' require(usl)
